from setuptools import setup, find_packages

setup(
    name="sorcerun",
    version="0.1",
    packages=find_packages(),
    install_requires=[
        "click",
    ],
    entry_points="""
        [console_scripts]
        sorcerun=sorcerun_package.cli:hello
    """,
)
